@@ -1,15 +1,16 @@
-# from SimpleStepperDriverV1 import SimpleStepperDriverV1
-# import time
+from SimpleStepperDriverV1 import SimpleStepperDriverV1
+import time
 
 
 
-# ssd = SimpleStepperDriverV1(method='rtu',serialPort = '/dev/ttyACM0')
+ssd = SimpleStepperDriverV1(method='rtu',serialPort = '/dev/ttyACM0')
 
 # ssd.writeD0(True)
 # print(ssd.readA5(),ssd.readA4())
+ssd.on()
 # ssd.on()
 # ssd.off()
-# ssd.go_forward(steps_per_second=20,steps=200)
+ssd.go_forward(steps_per_second=20)
 
 
 # while(1):
